package com.muller.awarenessapp.activities;

import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import android.Manifest;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import com.google.android.gms.awareness.Awareness;
import com.google.android.gms.awareness.snapshot.DetectedActivityResponse;
import com.google.android.gms.location.ActivityRecognitionResult;
import com.google.android.gms.tasks.OnSuccessListener;
import com.muller.awarenessapp.Const;
import com.muller.awarenessapp.R;

import java.util.List;

/**
 * Activity with list of detected fence activities and their confidence number
 */
public class DetectedActivity extends AppCompatActivity {
    private TextView tvDetected;
    private Handler handler = new Handler();

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_fence_activities);

    }

    /**
     * New thread which shows toast and sets text of detected fence activites every
     * three seconds
     */
    private Runnable r = new Runnable() {
        @Override
        public void run() {
            Toast.makeText(DetectedActivity.this, "Refreshed", Toast.LENGTH_SHORT).show();
            setText();
            handler.postDelayed(r, 3000);
        }
    };

    @Override
    protected void onStart() {
        super.onStart();
        tvDetected = findViewById(R.id.tvDetected);
        checkPermission();
    }

    /**
     * Reaction for start button, starts getting and showing fence activities.
     * @param v View that is triggering this method
     */
    public void startClick(View v) {
        r.run();
    }

    /**
     * Reaction for stop button, stops getting and refreshing fence activities.
     * @param v View that is triggering this method
     */
    public void stopClick(View v) {
        handler.removeCallbacks(r);
    }

    /**
     * Method which checks activity recognition permission
     */
    private void checkPermission() {
        if (ContextCompat.checkSelfPermission(this, Manifest.permission.ACTIVITY_RECOGNITION)
                != PackageManager.PERMISSION_GRANTED) {
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
                ActivityCompat.requestPermissions(this,
                        new String[]{Manifest.permission.ACTIVITY_RECOGNITION},
                        Const.ACTIVITY_REQ_CODE);
            }
            else {
                ActivityCompat.requestPermissions(this,
                        new String[]{"com.google.android.gms.permission.ACTIVITY_RECOGNITION"},
                        Const.ACTIVITY_REQ_CODE);
            }
        }
    }

    /**
     * Method which is getting and after that setting fence activites
     */
    public void setText() {
        Awareness.getSnapshotClient(this).getDetectedActivity()
                .addOnSuccessListener(new OnSuccessListener<DetectedActivityResponse>() {
                    @Override
                    public void onSuccess(DetectedActivityResponse dar) {
                        ActivityRecognitionResult arr = dar.getActivityRecognitionResult();
                        com.google.android.gms.location.DetectedActivity probableActivity = arr.getMostProbableActivity();

                        List<com.google.android.gms.location.DetectedActivity> activities = arr.getProbableActivities();

                        StringBuilder sb = new StringBuilder();
                        for ( com.google.android.gms.location.DetectedActivity da : activities) {
                            sb.append(da.toString() + "\n");
                        }

                        tvDetected.setText(sb);
                    }
                });


    }
}