package com.muller.awarenessapp.activities;

import androidx.appcompat.app.AppCompatActivity;

import android.app.AlertDialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.View;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.Switch;
import android.widget.Toast;

import com.muller.awarenessapp.Const;
import com.muller.awarenessapp.R;
import com.muller.awarenessapp.io.Fences;

/**
 * Activity with basic setting of the application
 */
public class SettingsActivity extends AppCompatActivity {
    EditText etRadius;
    Switch swDebug;
    ImageView ivInfo;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_settings);

        ivInfo = findViewById(R.id.ivInfoDebug);
        ivInfo.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                AlertDialog alertDialog = new AlertDialog.Builder(SettingsActivity.this, R.style.AlertDialogTheme).create();
                alertDialog.setTitle("Debug information");
                alertDialog.setMessage("Show information about received fences in BroadcastReceiver\n with key and state, where " +
                        "1 = false, 2 = true, 0 = unknown");
                alertDialog.setButton(AlertDialog.BUTTON_NEUTRAL, "OK",
                        new DialogInterface.OnClickListener() {
                            public void onClick(DialogInterface dialog, int which) {
                                dialog.dismiss();
                            }
                        });
                alertDialog.show();
            }
        });
        etRadius = findViewById(R.id.etRadius);
        etRadius.setText(String.valueOf(Fences.getInstance().getRadius()));

        swDebug = findViewById(R.id.swDebug);
        swDebug.setChecked(Fences.getInstance().isDebug());
        swDebug.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean isChecked) {
                Fences.getInstance().setDebug(isChecked);
            }
        });
    }

    /**
     * Reaction for save values button, validates inputs and navigates back to the main Activity
     * @param v View that is triggering this method
     */
    public void saveValuesClick(View v) {
        int radius;
        try {
            radius = Integer.parseInt(etRadius.getText().toString());
        }
         catch (NumberFormatException nfe) {
             Toast.makeText(this, "Radius must be number", Toast.LENGTH_SHORT).show();
             return;
         }

        if (radius <= 0) {
            Toast.makeText(this, "Radius must be greater than 0", Toast.LENGTH_SHORT).show();
        }
        else {
            Fences.getInstance().setRadius(radius);
            Fences.getInstance().writeSettings(radius);
            Toast.makeText(this, "Values saved", Toast.LENGTH_SHORT).show();
            Fences.getInstance().registerFences(this);

            if (Fences.getInstance().isDebug()) {
                Toast.makeText(this, "FENCES RE-REGISTERED", Toast.LENGTH_SHORT).show();
            }
            super.onBackPressed();
        }
    }

    /**
     * Reaction for set default button, set default values of switch and radius
     * @param v View that is triggering this method
     */
    public void setDefaultClick(View v) {
        etRadius.setText(String.valueOf(Const.DEF_RADIUS));
        swDebug.setChecked(false);
    }

    @Override
    public void onBackPressed() {
        Fences.getInstance().setDebug(false);
        super.onBackPressed();
    }
}