package com.muller.awarenessapp.activities;

import androidx.appcompat.app.AppCompatActivity;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.muller.awarenessapp.R;
import com.muller.awarenessapp.adapters.ProductAdapter;
import com.muller.awarenessapp.dialogs.LocationDialog;
import com.muller.awarenessapp.dialogs.ProductEditDialog;
import com.muller.awarenessapp.fences.ShoppingLocation;

/**
 * Activity with info of a particular location and its product list and buttons to edit these objects
 */
public class ShoppingInfoActivity extends AppCompatActivity implements ProductEditDialog.DialogListener, LocationDialog.DialogListener {
    private static final String TAG = "LocationInfoActivity";
    private ShoppingLocation shoppingLocation;
    private ProductAdapter adapter;
    private int selectedPosition;
    private TextView tvLocation;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_shopping_info);
        shoppingLocation = (ShoppingLocation)getIntent().getSerializableExtra("Location");
        tvLocation = findViewById(R.id.tvLocationName);
        tvLocation.setText(shoppingLocation.getName());
        setAdapter();
    }

    /**
     * Passes the location back to the ShoppingActivity
     */
    @Override
    public void onBackPressed() {
        Intent returnIntent = new Intent();
        returnIntent.putExtra("Location", shoppingLocation);
        Log.e(TAG, "onBackPressed: " + shoppingLocation.toString() + " resultOK " + Activity.RESULT_OK);
        setResult(Activity.RESULT_OK, returnIntent);
        super.onBackPressed();
    }

    /**
     * Reaction for add product button, adds new product to the list
     * @param v View that is triggering this method
     */
    public void addProductClick(View v) {
        EditText etProduct = findViewById(R.id.etProduct);
        String product = etProduct.getText().toString();

        if (!product.equals("")) {
            adapter.add(product);
            etProduct.setText("");
        }
        else {
            Toast.makeText(this, "Empty product name", Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Reaction for edit button, opens up editing dialog
     * @param v View that is triggering this method
     */
    public void editClick(View v) {
        LocationDialog dialog = new LocationDialog(shoppingLocation);
        dialog.show(getSupportFragmentManager(), "dialog");
    }

    /**
     * Method which sets listView and its adapter
     */
    private void setAdapter() {
        adapter = new ProductAdapter(this, R.layout.listview_row_product, shoppingLocation.getProducts());
        ListView listView = findViewById(R.id.lvProducst);
        listView.setAdapter(adapter);
        setListViewListener(listView);
    }

    /**
     * Method which sets listener for listView, creates new dialog for editing if clicked on its
     * item
     * @param listView listView whose listener will be set
     */
    private void setListViewListener(final ListView listView) {
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int position, long arg) {
                selectedPosition = position;
                ProductEditDialog dialog = new ProductEditDialog(shoppingLocation.getProducts().get(position));
                dialog.show(getSupportFragmentManager(), "dialog");
            }
        });
    }

    /**
     * Edit particular product in ListView
     * @param productName name of the product
     */
    @Override
    public void editTexts(String productName) {
        shoppingLocation.getProducts().set(selectedPosition, productName);
        adapter.notifyDataSetChanged();
    }

    /**
     * After validation which occurs inside LocationDialog class applies inputs
     * @param name name of the location
     * @param longitude longitude of the location
     * @param latitude latitude of the location
     */
    public void applyTexts(String name, double longitude, double latitude) {
        tvLocation.setText(name);
        shoppingLocation.setName(name);
        shoppingLocation.setLongitude(longitude);
        shoppingLocation.setLatitude(latitude);
    }
}