package com.muller.awarenessapp.activities;

import androidx.appcompat.app.AppCompatActivity;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

import com.muller.awarenessapp.R;
import com.muller.awarenessapp.adapters.TaskAdapter;
import com.muller.awarenessapp.dialogs.LocationDialog;
import com.muller.awarenessapp.dialogs.TaskEditDialog;
import com.muller.awarenessapp.fences.TodoLocation;
import com.muller.awarenessapp.fences.TodoTask;

/**
 * Activity with info of a particular location and its to do list and buttons to edit these objects
 */
public class TodoInfoActivity extends AppCompatActivity implements TaskEditDialog.DialogListener, LocationDialog.DialogListener {
    private static final String TAG = "TodoInfoActivity";
    private TodoLocation todoLocation;
    private TaskAdapter adapter;
    private TextView tvLocation;
    private TodoLocation selected;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_todo_info);
        todoLocation = (TodoLocation) getIntent().getSerializableExtra("Location");
        tvLocation = findViewById(R.id.tvTask);
        tvLocation.setText(todoLocation.getName());
        setAdapter();
    }

    public void editClick(View v) {
        LocationDialog dialog = new LocationDialog(todoLocation);
        dialog.show(getSupportFragmentManager(), "dialog");
    }


    /**
     * Passes the location back to the TodoActivity
     */
    @Override
    public void onBackPressed() {
        Intent returnIntent = new Intent();
        returnIntent.putExtra("Location", todoLocation);
        setResult(Activity.RESULT_OK, returnIntent);
        super.onBackPressed();
    }

    /**
     * Reaction for add task button, adds new task to the list
     * @param v View that is triggering this method
     */
    public void addTaskClick(View v) {
        EditText etTask = findViewById(R.id.etTask);
        String task = etTask.getText().toString();

        if (!task.equals("")) {
            adapter.add(new TodoTask(task, false));
            etTask.setText("");
        }
        else {
            Toast.makeText(this, "Empty product name", Toast.LENGTH_SHORT).show();
        }
    }

    /**
     * Method which sets listView and its adapter
     */
    private void setAdapter() {
        adapter = new TaskAdapter(this, R.layout.listview_row_todotask, todoLocation.getTodoTasks());
        ListView listView = findViewById(R.id.lvTasks);
        listView.setAdapter(adapter);
        setListViewListener(listView);
    }

    /**
     * Method which sets listener for listView, creates new dialog for editing if clicked on its
     * item
     * @param listView listView whose listener will be set
     */
    private void setListViewListener(final ListView listView) {
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {
            @Override
            public void onItemClick(AdapterView<?> adapterView, View view, int position, long arg) {
                TaskEditDialog dialog = new TaskEditDialog(position, todoLocation.getTodoTasks().get(position).getTask(), todoLocation.getTodoTasks().get(position).getDescription());
                dialog.show(getSupportFragmentManager(), "dialog");
            }
        });
    }

    /**
     * Edit particular task in ListView
     * @param taskName name of the task
     * @param position position of the task
     */
    @Override
    public void editTexts(String taskName, String description, int position) {
        todoLocation.getTodoTasks().get(position).setTask(taskName);
        todoLocation.getTodoTasks().get(position).setDescription(description);
        adapter.notifyDataSetChanged();
    }

    /**
     * After validation which occurs inside LocationDialog class applies inputs
     * @param name name of the location
     * @param longitude longitude of the location
     * @param latitude latitude of the location
     */
    @Override
    public void applyTexts(String name, double longitude, double latitude) {
        tvLocation.setText(name);
        todoLocation.setName(name);
        todoLocation.setLongitude(longitude);
        todoLocation.setLatitude(latitude);
    }
}