package com.muller.awarenessapp.dialogs;

import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatDialogFragment;

import com.muller.awarenessapp.R;

/**
 * Class represents dialog with inputs for product
 */
public class ProductEditDialog extends AppCompatDialogFragment {
    private String oldName;
    private EditText etProductName;
    private ProductEditDialog.DialogListener listener;

    public ProductEditDialog(String oldName) {
        this.oldName = oldName;
    }

    @NonNull
    @Override
    public android.app.Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity(), R.style.AlertDialogTheme);

        LayoutInflater inflater = getActivity().getLayoutInflater();
        View view = inflater.inflate(R.layout.dialog_edit_product, null);
        etProductName = view.findViewById(R.id.etEditProduct);
        etProductName.setText(oldName);

        builder.setView(view)
                .setTitle("Edit product name")
                .setPositiveButton("SAVE", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        String name = etProductName.getText().toString();
                        if (name.isEmpty()) {
                            Toast.makeText(getActivity(), "Invalid input", Toast.LENGTH_SHORT).show();
                        }
                        else {
                            listener.editTexts(name);
                        }
                    }
                })
                .setNegativeButton("CANCEL", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {

                    }
                });

        return builder.create();
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        try {
            listener = (ProductEditDialog.DialogListener)context;
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Interface for communication with Activity
     */
    public interface DialogListener {
        void editTexts(String productName);
    }
}
