package com.muller.awarenessapp.dialogs;

import android.content.Context;
import android.content.DialogInterface;
import android.os.Bundle;
import android.view.LayoutInflater;
import android.view.View;
import android.widget.EditText;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatDialogFragment;

import com.muller.awarenessapp.R;

/**
 * Class represents dialog with inputs for task
 */
public class TaskEditDialog extends AppCompatDialogFragment {
    private int position;               //position from listView
    private String oldName;
    private String oldDescription;
    private EditText etTaskName;
    private EditText etDescription;
    private TaskEditDialog.DialogListener listener;

    public TaskEditDialog(int position, String oldName, String oldDescription) {
        this.position = position;
        this.oldName = oldName;
        this.oldDescription = oldDescription;
    }

    @NonNull
    @Override
    public android.app.Dialog onCreateDialog(@Nullable Bundle savedInstanceState) {
        AlertDialog.Builder builder = new AlertDialog.Builder(getActivity(), R.style.AlertDialogTheme);

        LayoutInflater inflater = getActivity().getLayoutInflater();
        View view = inflater.inflate(R.layout.dialog_edit_task, null);
        etTaskName = view.findViewById(R.id.etTask);
        etTaskName.setText(oldName);

        etDescription = view.findViewById(R.id.etDescription);
        etDescription.setText(oldDescription);

        builder.setView(view)
                .setTitle("Edit task")
                .setPositiveButton("SAVE", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        String name = etTaskName.getText().toString();
                        String description = etDescription.getText().toString();
                        listener.editTexts(name, description, position);
                    }
                })
                .setNegativeButton("CANCEL", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {

                    }
                });

        return builder.create();
    }

    @Override
    public void onAttach(@NonNull Context context) {
        super.onAttach(context);
        try {
            listener = (TaskEditDialog.DialogListener)context;
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * Interface for communication with Activity
     */
    public interface DialogListener {
        void editTexts(String taskName, String description, int position);
    }
}
