package com.muller.awarenessapp.fences;

import android.app.Notification;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;

import com.google.android.gms.awareness.Awareness;
import com.google.android.gms.awareness.fence.AwarenessFence;
import com.google.android.gms.awareness.fence.FenceUpdateRequest;
import com.google.android.gms.awareness.fence.HeadphoneFence;
import com.google.android.gms.awareness.state.HeadphoneState;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.muller.awarenessapp.App;
import com.muller.awarenessapp.Const;
import com.muller.awarenessapp.R;
import com.muller.awarenessapp.activities.ReleaseActivity;

import java.io.Serializable;
import java.util.Calendar;
import java.util.Date;

/**
 * Class represents Release fence object
 */
public class Release implements Serializable, IFence {
    private static final long serialVersionUID = 1L;
    private int id;
    private Date date;
    private String artist;
    private String album;
    private boolean seen;

    public Release(int id, Date date, String artist, String album, Boolean seen) {
        this.id = id;
        this.date = date;
        this.artist = artist;
        this.album = album;
        this.seen = seen;
    }

    public int getId() {
        return id;
    }

    public void setId(int id) {
        this.id = id;
    }

    public Date getDate() {
        return date;
    }

    public void setDate(Date date) {
        this.date = date;
    }

    public String getArtist() {
        return artist;
    }

    public void setArtist(String artist) {
        this.artist = artist;
    }

    public String getAlbum() {
        return album;
    }

    public void setAlbum(String album) {
        this.album = album;
    }

    public boolean isSeen() {
        return seen;
    }

    public void setSeen(boolean seen) {
        this.seen = seen;
    }

    public String getStringDate() {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        int month = calendar.get(Calendar.MONTH) + 1;
        return calendar.get(Calendar.DAY_OF_MONTH) + "/" + month + "/" + calendar.get(Calendar.YEAR);
    }

    @Override
    public String toString() {
        return  + id + ";" + date + ";" + artist + ";" + album + ";";
    }

    @Override
    public String getKey() {
        return Const.HEADPHONES_FENCE_KEY + id;
    }

    @Override
    public void sendNotification(Context context) {
        Calendar calNow = Calendar.getInstance();
        Calendar cal = Calendar.getInstance();
        if (this.getDate() != null) {
            cal.setTime(this.getDate());

            if (calNow.after(cal) && !this.isSeen()) {
                Intent activityIntent = new Intent(context, ReleaseActivity.class);
                PendingIntent contentIntent = PendingIntent.getActivity(context, 0, activityIntent, PendingIntent.FLAG_UPDATE_CURRENT);

                NotificationManagerCompat notificationManager = NotificationManagerCompat.from(context);
                Notification notification = new NotificationCompat.Builder(context, App.CHANNEL_1)
                        .setSmallIcon(R.mipmap.ic_launcher)
                        .setContentTitle("New music released")
                        .setContentText("Album: " + this.getAlbum() + ", Artist: " + this.getArtist())
                        .setCategory(NotificationCompat.CATEGORY_MESSAGE)
                        .setContentIntent(contentIntent)
                        .setAutoCancel(true)
                        .build();

                //if update, use same id
                notificationManager.notify(this.getId() + Const.RELEASE_NOTIFICATION, notification);
            }
        }
    }

    @Override
    public void registerFence(Context context, PendingIntent pendingIntent) {
        final String key = this.getKey();
        AwarenessFence headphonesFence = HeadphoneFence.during(HeadphoneState.PLUGGED_IN);
        Awareness.getFenceClient(context).updateFences(new FenceUpdateRequest.Builder()
                    .addFence(this.getKey(), headphonesFence, pendingIntent)
                    .build())
                    .addOnSuccessListener(new OnSuccessListener<Void>() {
                        @Override
                        public void onSuccess(Void aVoid) {
                            Log.e("Release ", "Fence was successfully registered. " + key);
                        }
                    })
                    .addOnFailureListener(new OnFailureListener() {
                        @Override
                        public void onFailure(@NonNull Exception e) {
                            Log.e("Release", "Fence could not be registered: " + e);
                        }
                    });

    }

    @Override
    public void unregisterFence(Context context) {
        Awareness.getFenceClient(context).updateFences(new FenceUpdateRequest.Builder()
                .removeFence(this.getKey())
                .build())
                .addOnSuccessListener(new OnSuccessListener<Void>() {
                    @Override
                    public void onSuccess(Void aVoid) {
                        //Log.i(TAG, "Fence was successfully unregistered.");
                    }
                })
                .addOnFailureListener(new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        //Log.e(TAG, "Fence could not be unregistered: " + e);
                    }
                });
    }
}
