package com.muller.awarenessapp.fences;

import android.Manifest;
import android.app.Notification;
import android.app.PendingIntent;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.core.app.ActivityCompat;
import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;

import com.google.android.gms.awareness.Awareness;
import com.google.android.gms.awareness.fence.AwarenessFence;
import com.google.android.gms.awareness.fence.FenceUpdateRequest;
import com.google.android.gms.awareness.fence.LocationFence;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.muller.awarenessapp.App;
import com.muller.awarenessapp.Const;
import com.muller.awarenessapp.R;
import com.muller.awarenessapp.activities.ShoppingActivity;
import com.muller.awarenessapp.io.Fences;

import java.util.ArrayList;

/**
 * Class represents ShoppingLocation fence object, extends base Location
 */
public class ShoppingLocation extends Location implements IFence {
    private ArrayList<String> products;

    public ShoppingLocation(int id, String name, double longitude, double latitude) {
        super(id, name, longitude, latitude);
        this.products = new ArrayList<>();
    }

    public ArrayList<String> getProducts() {
        if (products == null) {
            products = new ArrayList<String>();
            return products;
        }
        return products;
    }

    public void setProducts(ArrayList<String> products) {
        this.products = products;
    }

    @Override
    public void sendNotification(Context context) {
        Intent activityIntent = new Intent(context, ShoppingActivity.class);
        PendingIntent contentIntent = PendingIntent.getActivity(context, 0, activityIntent, PendingIntent.FLAG_UPDATE_CURRENT);

        NotificationManagerCompat notificationManager = NotificationManagerCompat.from(context);
        Notification notification = new NotificationCompat.Builder(context, App.CHANNEL_1)
                .setSmallIcon(R.mipmap.ic_launcher)
                .setContentTitle("You have products to buy")
                .setContentText("Location \"" + this.getName() + "\", number of products: " + this.getProducts().size())
                .setCategory(NotificationCompat.CATEGORY_MESSAGE)
                .setAutoCancel(true)
                .setContentIntent(contentIntent)
                .build();

        //update same id
        notificationManager.notify(this.getId() + Const.SHOP_LOC_NOTIFICATION, notification);
    }

    @Override
    public void registerFence(Context context, PendingIntent pendingIntent) {
        if (ActivityCompat.checkSelfPermission(context, Manifest.permission.ACCESS_FINE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            Toast.makeText(context, "Location permission is not granted, make sure to choose Allow all the time", Toast.LENGTH_SHORT).show();
            return;
        }
        final String key = this.getKey();
        Log.e("DEEEEBUG", "registerFence: " + this.getLatitude() + " " + this.getLongitude() + " " + Fences.getInstance().getRadius());
        AwarenessFence locationFence = LocationFence.in(this.getLatitude(), this.getLongitude(), Fences.getInstance().getRadius(), 1);
        Awareness.getFenceClient(context).updateFences(new FenceUpdateRequest.Builder()
                .addFence(this.getKey(), locationFence, pendingIntent)
                .build())
                .addOnSuccessListener(new OnSuccessListener<Void>() {
                    @Override
                    public void onSuccess(Void aVoid) {
                        Log.e("Location", "Location Fence was successfully registered. " + key);
                    }
                })
                .addOnFailureListener(new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        Log.e("Location", key + " could not be registered: " + e);
                    }
                });
    }

    @Override
    public void unregisterFence(Context context) {
        Awareness.getFenceClient(context).updateFences(new FenceUpdateRequest.Builder()
                .removeFence(this.getKey())
                .build())
                .addOnSuccessListener(new OnSuccessListener<Void>() {
                    @Override
                    public void onSuccess(Void aVoid) {
                        //Log.i(TAG, "Fence was successfully unregistered.");
                    }
                })
                .addOnFailureListener(new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        //Log.e(TAG, "Fence could not be unregistered: " + e);
                    }
                });
    }

    @Override
    public String getKey() {
        return Const.SHOP_LOCATION_FENCE_KEY + this.getId();
    }
}
