package com.muller.awarenessapp.receivers;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.text.TextUtils;
import android.util.Log;
import android.widget.Toast;

import com.google.android.gms.awareness.fence.FenceState;
import com.muller.awarenessapp.fences.IFence;
import com.muller.awarenessapp.io.Fences;

import java.util.ArrayList;

/**
 * Receiver class which takes care of broadcast which are sent to it if some fences
 * are triggered
 * Iterate through all fences and checks if some of the keys are equal, if so then checks
 * the state of the received fence, when its true calls method for sending notification
 */
public class Receiver extends BroadcastReceiver {
    private static final String TAG = "Receiver";

    public void onReceive(Context context, Intent intent) {
        Log.e(TAG, "RECEIVE");
        FenceState fenceState = FenceState.extract(intent);
        ArrayList<IFence> fences = Fences.getInstance().getFences();
        for (IFence fence : fences) {
            Log.e(TAG, "onReceive: INotifiable " + fence.getKey() + " " + fenceState.getFenceKey());
            if (TextUtils.equals(fenceState.getFenceKey(), fence.getKey())) {
                if (Fences.getInstance().isDebug()) {
                    Toast.makeText(context, "RECEIVE " + "key: " + fence.getKey() + "; state: " + fenceState.getCurrentState(), Toast.LENGTH_SHORT).show();
                }
                switch (fenceState.getCurrentState()) {
                    case FenceState.TRUE:
                        fence.sendNotification(context);
                        Log.e(TAG, "onReceive: true id:" + fence.getKey());
                        break;
                    case FenceState.FALSE:
                        Log.e(TAG, "onReceive: false id:" + fence.getKey());
                        break;
                    case FenceState.UNKNOWN:
                        Log.e(TAG, "onReceive: unknwn id:" + fence.getKey());
                        break;
                }
            }
        }
    }
}
