package com.muller.awarenessapp.services;

import android.app.Notification;
import android.app.PendingIntent;
import android.app.Service;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.IBinder;

import androidx.annotation.Nullable;
import androidx.core.app.NotificationCompat;

import com.muller.awarenessapp.App;
import com.muller.awarenessapp.Const;
import com.muller.awarenessapp.activities.MainActivity;
import com.muller.awarenessapp.R;
import com.muller.awarenessapp.receivers.Receiver;
import com.muller.awarenessapp.io.Fences;

/**
 * Class represents foreground service to be able to receive broadcast even when app is closed
 */
public class ReceiverService extends Service {
    private final int FOREGROUND_ID = -1;

    public ReceiverService() {
    }

    @Nullable
    @Override
    public IBinder onBind(Intent intent) {
        return null;
    }


    /**
     * Registern receiver and read and register all stored fences from files
     */
    @Override
    public void onCreate() {
        super.onCreate();
        Notification notification = getMainNotification();
        startForeground(FOREGROUND_ID, notification);

        Receiver receiver = new Receiver();
        registerReceiver(receiver, new IntentFilter(Const.FENCE_RECEIVER_ACTION));

        Fences.getInstance().readFences(this);
        Fences.getInstance().registerFences(this);
    }

    /**
     * Execution of service will star on calling this method
     */
    @Override
    public int onStartCommand(Intent intent, int flags, int startId) {

        // returns the status
        // of the program
        return START_NOT_STICKY;
    }

    /**
     * Creates main notification of the app, notification will be always shown when app is running
     * @return
     */
    private Notification getMainNotification() {
        Intent activityIntent = new Intent(this, MainActivity.class);
        PendingIntent contentIntent = PendingIntent.getActivity(this, 0, activityIntent, PendingIntent.FLAG_UPDATE_CURRENT);

        return new NotificationCompat.Builder(this, App.CHANNEL_1)
                .setSmallIcon(R.mipmap.ic_launcher)
                .setContentTitle("Aware assistant is running")
                .setContentIntent(contentIntent)
                .build();
    }
}
