package com.muller.awarenessapp.testfences;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import android.Manifest;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.content.pm.PackageManager;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.widget.TextView;

import com.google.android.gms.awareness.Awareness;
import com.google.android.gms.awareness.fence.AwarenessFence;
import com.google.android.gms.awareness.fence.DetectedActivityFence;
import com.google.android.gms.awareness.fence.FenceState;
import com.google.android.gms.awareness.fence.FenceUpdateRequest;
import com.google.android.gms.awareness.fence.LocationFence;
import com.google.android.gms.location.DetectedActivity;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.muller.awarenessapp.Const;
import com.muller.awarenessapp.R;

/**
 * TESTING CLASS
 */

public class FenceLocation extends AppCompatActivity {
    private static final String TAG = "FENCELOCATION";
    private static final String LOCATION_FENCE_KEY = "LOCATION_FENCE_KEY";
    private static final String VEHICLE_FENCE_KEY = "VEHICLE_FENCE_KEY";
    private static final String LOCATION_VEHICLE_FENCE_KEY = "LOCATION_VEHICLE_FENCE_KEY";

    private PendingIntent pendingIntent;
    private LocationFenceReceiver locationFenceReceiver;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_fence_location);
        locationFenceReceiver = new LocationFenceReceiver();
        Intent intent = new Intent(Const.FENCE_RECEIVER_ACTION);
        pendingIntent = PendingIntent.getBroadcast(this, 1, intent, 0);
    }

    @Override
    protected void onStart() {
        super.onStart();
        registerFence();
        registerReceiver(locationFenceReceiver, new IntentFilter(Const.FENCE_RECEIVER_ACTION));
    }

    private void registerFence() {
        if (ContextCompat.checkSelfPermission(this, Manifest.permission.ACCESS_FINE_LOCATION) !=
                PackageManager.PERMISSION_GRANTED) {
            ActivityCompat.requestPermissions(
                    this,
                    new String[]{Manifest.permission.ACCESS_FINE_LOCATION},
                    Const.LOCATION_REQ_CODE
            );
        }
        else {
            AwarenessFence locationFence = LocationFence.in(49.428858, 13.885815, 200, 1);
            AwarenessFence vehicleFence = DetectedActivityFence.during(DetectedActivity.IN_VEHICLE);
            AwarenessFence locationVehicleFence = AwarenessFence.and(locationFence, vehicleFence);

            Awareness.getFenceClient(this).updateFences(new FenceUpdateRequest.Builder()
                    .addFence(LOCATION_FENCE_KEY, locationFence, pendingIntent)
                    //.addFence(VEHICLE_FENCE_KEY, vehicleFence, pendingIntent)
                    .addFence(LOCATION_VEHICLE_FENCE_KEY, locationVehicleFence, pendingIntent)
                    .build())
                    .addOnSuccessListener(new OnSuccessListener<Void>() {
                        @Override
                        public void onSuccess(Void aVoid) {
                            Log.i(TAG, "Fence was successfully registered.");
                        }
                    })
                    .addOnFailureListener(new OnFailureListener() {
                        @Override
                        public void onFailure(@NonNull Exception e) {
                            Log.e(TAG, "Fence could not be registered: " + e);
                        }
                    });
        }
    }

    class LocationFenceReceiver extends BroadcastReceiver {
        TextView tvLocation = findViewById(R.id.tvLocation);
        TextView tvLocationVehicle = findViewById(R.id.tvLocationVehicle);

        @Override
        public void onReceive(Context context, Intent intent) {
            FenceState fenceState = FenceState.extract(intent);

            if (TextUtils.equals(fenceState.getFenceKey(), LOCATION_FENCE_KEY)) {
                switch(fenceState.getCurrentState()) {
                    case FenceState.TRUE:
                        tvLocation.setText("IN AREA");
                        break;
                    case FenceState.FALSE:
                        tvLocation.setText("OUT OF AREA");
                        break;
                    case FenceState.UNKNOWN:
                        tvLocation.setText("UNKNOWN");
                        break;
                }
            }
            else if (TextUtils.equals(fenceState.getFenceKey(), LOCATION_VEHICLE_FENCE_KEY)) {
                switch(fenceState.getCurrentState()) {
                    case FenceState.TRUE:
                        tvLocationVehicle.setText("IN AREA AND VEHICLE");
                        break;
                    case FenceState.FALSE:
                        tvLocation.setText("OUT OF AREA AND VEHICLE");
                        break;
                    case FenceState.UNKNOWN:
                        tvLocation.setText("UNKNOWN");
                        break;
                }
            }
        }
    }
}