package com.muller.awarenessapp.testfences;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.NotificationCompat;
import androidx.core.app.NotificationManagerCompat;

import android.app.Notification;
import android.app.PendingIntent;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.text.TextUtils;
import android.util.Log;
import android.widget.TextView;

import com.google.android.gms.awareness.Awareness;
import com.google.android.gms.awareness.fence.AwarenessFence;
import com.google.android.gms.awareness.fence.FenceState;
import com.google.android.gms.awareness.fence.FenceUpdateRequest;
import com.google.android.gms.awareness.fence.TimeFence;
import com.google.android.gms.tasks.OnFailureListener;
import com.google.android.gms.tasks.OnSuccessListener;
import com.muller.awarenessapp.R;

import java.util.TimeZone;

import static com.muller.awarenessapp.App.CHANNEL_1;

/**
 * TESTING CLASS
 */

public class FenceTimeActivity extends AppCompatActivity {
    private static final String TAG = "FENCETIME";
    public static final String FENCE_RECEIVER_ACTION = "com.muller.awarenessapp.FENCE_RECEIVER_ACTION";
    private static final String TIME_FENCE_KEY = "TIME_FENCE_KEY";
    private static final long HOURS_IN_MILLIS = 3600000;
    private static final long MINUTES_IN_MILLIS = 60000;
    private PendingIntent pendingIntent;
    private TimeFenceReceiver timeFenceReceiver;
    NotificationManagerCompat notificationManager;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_fence_time);
        timeFenceReceiver = new TimeFenceReceiver();
        Intent intent = new Intent(FENCE_RECEIVER_ACTION);
        pendingIntent = PendingIntent.getBroadcast(this, 1, intent, 0);
        notificationManager = NotificationManagerCompat.from(this);
        registerReceiver(timeFenceReceiver, new IntentFilter(FENCE_RECEIVER_ACTION));
        registerFence();
    }



    private void registerFence() {
        //TimeZone.getDefault()
        //AwarenessFence timeFence = TimeFence.inInterval(currentTimeMillis, currentTimeMillis + 1L * 2L * 60L * 1000L);
        //AwarenessFence timeFence = TimeFence.inDailyInterval(TimeZone.getDefault(), (18L * 60L * 60L * 1000L) + (35L * 60L * 1000L), (18L * 60L * 60L * 1000L) + (37L * 60L * 1000L));
        AwarenessFence timeFence = TimeFence.inDailyInterval(TimeZone.getDefault(), 22 * HOURS_IN_MILLIS + 13 * MINUTES_IN_MILLIS, 24 * HOURS_IN_MILLIS + 0 * MINUTES_IN_MILLIS);

        Awareness.getFenceClient(this).updateFences(new FenceUpdateRequest.Builder()
                .addFence(TIME_FENCE_KEY, timeFence, pendingIntent)
                .build())
                .addOnSuccessListener(new OnSuccessListener<Void>() {
                    @Override
                    public void onSuccess(Void aVoid) {
                        Log.e(TAG, "Fence was successfully registered.");
                    }
                })
                .addOnFailureListener(new OnFailureListener() {
                    @Override
                    public void onFailure(@NonNull Exception e) {
                        Log.e(TAG, "Fence could not be registered: " + e);
                    }
                });
    }

    class TimeFenceReceiver extends BroadcastReceiver {
        TextView tvTime = findViewById(R.id.tvTime);

        @Override
        public void onReceive(Context context, Intent intent) {
            FenceState fenceState = FenceState.extract(intent);

            if (TextUtils.equals(fenceState.getFenceKey(), TIME_FENCE_KEY)) {
                switch(fenceState.getCurrentState()) {
                    case FenceState.TRUE:
                        tvTime.setText("ITS TIME");
                        Notification notification = new NotificationCompat.Builder(context, CHANNEL_1)
                                .setSmallIcon(R.mipmap.ic_launcher)
                                .setContentTitle("Time")
                                .setContentText("Fence")
                                .setCategory(NotificationCompat.CATEGORY_MESSAGE)
                                .build();

                        //update same id
                        notificationManager.notify(1, notification);
                        break;
                    case FenceState.FALSE:
                        tvTime.setText("NOT THAT TIME");
                        break;
                    case FenceState.UNKNOWN:
                        tvTime.setText("UNKNOWN");
                        break;
                }
            }
        }
    }
}